#!/bin/bash

# LHS experiment number (corresponds to the line number in the matrix of experiments)
#runnum="100"       # should be a 3 digit number.
runnum="XIXIXIXIXIX"

# name of the run:
namerun="AN40T"$runnum

tmodelend="100000."
tmodelbegin="0."
tmodellength="100000."


parallel="no" # "yes or no?"
proc_number="4" # number of processor used
ppn_number=$proc_number # number of cpus (ppn)
exename="Ant-40"

queue="long"  # specify queue used : short, medium, long, xlong...

# Files used
grisli_run_file="Master-files/grisli.run.lsce"
param_file="Master-files/Param/anteis1_param_list_lhs-nolin.dat"     # param file
TEMPS_NETCDF_file="Master-files/Param/lhs_TEMPS-NETCDF.dat"          # TEMPS-NETCDF.dat
module_choix_file="Master-files/module_choix-antar40-0.4-nolin.f90"  # module choix

#Revision number :
rev=`svn info | grep "vision" | awk '{print $2}'`
echo "Code revision svn "$rev


echo "-------------------------------------"
echo "    Now launching run: "   $namerun
echo "      -------------------------      "

#--------------------------------------------------
# Check if times are ok:
#--------------------------------------------------

tcheck=`echo "$tmodelbegin + $tmodellength" | bc -l`
tcheckbis=`echo "$tmodelend + 0" | bc -l`
if [ $tcheck != $tcheckbis ]; then
    echo "The times provided are wrong!"
    echo $tcheck $tcheckbis
    echo "Tbegin:" $tmodelbegin ", Tend:" $tmodelend ", length:" $tmodellength
    exit 0
else
    echo "The times provided are correct."
fi

#--------------------------------------------------
# The different directories:
#--------------------------------------------------

LAUNCHING_DIR=`pwd`
GRISLI_DIR=${LAUNCHING_DIR%%/launching_area}
RUNDIR=${GRISLI_DIR}"/RUNS/"${namerun}
MODELMASTER=${GRISLI_DIR}"/SOURCES"
MODEL=${RUNDIR}"/SOURCES"


if [ -d $RUNDIR ]; then
    echo "This run exists, do you really want to overwrite?"
    echo "You have 3 sec. to do a ctr+c..."
    sleep 3
    echo "Ok, your choice."
else
    mkdir $RUNDIR
    echo "      Run will be in:"
    echo "  " $RUNDIR
fi

if [ -d $MODEL ]; then
    echo "model dir already created, cleaning up before copying files"
    rm -rf $MODEL"/"*
else
    mkdir $MODEL
fi
 
cp -R $MODELMASTER"/"* $MODEL"/."
svn status $MODELMASTER > $MODEL"/svn.status.txt"
svn diff $MODELMASTER > $MODEL"/svn.diff.txt"


if [ -d $RUNDIR"/bin" ]; then
    echo "exe in bin/"
else
    mkdir $RUNDIR"/bin"
fi

if [ -d $RUNDIR"/RESULTATS" ]; then
    echo "exe in RESULTATS/"
else
    mkdir $RUNDIR"/RESULTATS"
fi

if [ -d $RUNDIR"/INPUT" ]; then
    echo "inputs are linked to model master"
else
    echo "inputs will be linked to model master"
    mkdir $RUNDIR"/INPUT"
fi


    
echo "Now copying master files to the working directory:"
echo $RUNDIR
echo "And to the model directory:"
echo $MODEL


cp $TEMPS_NETCDF_file $MODEL"/Fichiers-parametres/TEMPS-NETCDF.dat"
cp $module_choix_file $MODEL"/Ant40_files/module_choix-antar40-0.4.f90"
cp $param_file $RUNDIR"/bin/anteis1_param_list.dat"
cp $grisli_run_file $RUNDIR"/bin/grisli.run"


cd $RUNDIR"/INPUT"
ln -sf $MODELMASTER"/../INPUT/ANTEIS1" .
ln -sf $MODELMASTER"/../INPUT/Forcage" .
ln -sf $MODELMASTER"/../INPUT/tracer.dat" .


#--------------------------------------------------
# parameter values:
#--------------------------------------------------

mnolin_fact="3."
nbiternolin_fact="5"

fichlhs=$LAUNCHING_DIR"/Master-files/LHS/LHS_values_4-params.dat"
expnum=`echo $runnum "* 1." | bc`
echo "LHS exp. number: " $expnum
head -$expnum $fichlhs | tail -1 > prov
# Keep a record of the values:
cp prov  $RUNDIR"/bin/LHS_values_4-params_run-"$expnum".dat"

enh_fact=`awk '{print $2}' prov`
bslope_fact=`awk '{print $3*100}' prov` 
ob_fact=`awk '{print (((($3*1000-2.75))/2.25)*0.5)+1.}' prov` # pour le Ob du beta de PISM (simple hydro) (ici entre 0.5 et 1.5)
kond0_fact=`awk '{print $4}' prov`
kt_fact=`awk '{print $5*25}' prov`

bexpo_fact="1."

infiltr_fact="1.e-3" #"1.e-3"



#--------------------------------------------------
# Replacing key words:
#--------------------------------------------------

# run spec.:
sed -i "s/RUNNAME/$namerun/" $RUNDIR"/bin/anteis1_param_list.dat"
sed -i "s/RUNTBEGIN/$tmodelbegin/" $RUNDIR"/bin/anteis1_param_list.dat"
sed -i "s/RUNTEND/$tmodelend/" $RUNDIR"/bin/anteis1_param_list.dat"

# submission script:
sed -i "s|SOURCESREP|$MODEL|" $RUNDIR"/bin/grisli.run"
sed -i "s|EXEREP|$RUNDIR\/bin|" $RUNDIR"/bin/grisli.run"
sed -i "s/RUNNAME/$namerun/" $RUNDIR"/bin/grisli.run"
sed -i "s/EXE_NAME/$exename/g" $RUNDIR"/bin/grisli.run"
sed -i "s|USERNAME|$USER|" $RUNDIR"/bin/grisli.run"

if [ $parallel = "yes" ]; then
    sed -i "s/QUEUE/${queue}p/" $RUNDIR"/bin/grisli.run"
    sed -i "s/PROC_NUMBER/$proc_number/" $RUNDIR"/bin/grisli.run"
    sed -i "s/PPN_NUMBER/$ppn_number/" $RUNDIR"/bin/grisli.run"
else
    sed -i "s/QUEUE/$queue/" $RUNDIR"/bin/grisli.run"
    sed -i "s/PROC_NUMBER/1/" $RUNDIR"/bin/grisli.run"
    sed -i "s/PPN_NUMBER/1/" $RUNDIR"/bin/grisli.run"
    sed -i "/export\ MKL_NUM_THREADS/d" $RUNDIR"/bin/grisli.run"
    sed -i "/export\ OMP_NUM_THREADS/d" $RUNDIR"/bin/grisli.run"
    sed -i "/export\ KMP_STACKSIZE/d" $RUNDIR"/bin/grisli.run"
fi

# param values:
sed -i "s/PARAMMNOLIN/$mnolin_fact/" $RUNDIR"/bin/anteis1_param_list.dat"
sed -i "s/PARAMNBITERNOLIN/$nbiternolin_fact/" $RUNDIR"/bin/anteis1_param_list.dat"
sed -i "s/PARAMENHFACT/$enh_fact/" $RUNDIR"/bin/anteis1_param_list.dat"
sed -i "s/PARAMINFILTR/$infiltr_fact/" $RUNDIR"/bin/anteis1_param_list.dat"
sed -i "s/PARAMKOND0/$kond0_fact/" $RUNDIR"/bin/anteis1_param_list.dat"
sed -i "s/PARAMBSLOPE/$bslope_fact/" $RUNDIR"/bin/anteis1_param_list.dat"
sed -i "s/PARAMBEXPO/$bexpo_fact/" $RUNDIR"/bin/anteis1_param_list.dat"
sed -i "s/PARAMOB/$ob_fact/" $RUNDIR"/bin/anteis1_param_list.dat"
sed -i "s/PARAMKT/$kt_fact/" $RUNDIR"/bin/anteis1_param_list.dat"

#--------------------------------------------------
# Submitting the job:
#--------------------------------------------------
cd $RUNDIR"/bin"
echo "submitting the job"
qsub grisli.run
echo "-------------------------------------"








